(function(){
    RE.inKbApp = typeof JavaInterface !== "undefined";
    function safeHtml(text, filter_quote) {
        if (text === undefined) {
            return "";
        }
        text = text.toString().replace(/&/g,'&amp;').replace(/</, '&lt;').replace(/>/, '&gt;');
        if (filter_quote) {
            text.replace(/"/g, '&quot;').replace(/'/g, '&#039;');
        }
        return text;
    }
    function getTextWidth(text){
        var span = document.createElement('span');
        span.innerText = text;
        span.style.fontSize = '.3rem';
        span.style.whiteSpace = 'pre-wrap';
        document.body.appendChild(span);
        var width = span.offsetWidth;
        document.body.removeChild(span);
        return width+1;
    }
    function isKbPanel(node) {
      if (node && node.nodeName == "DIV" && /\binnerApp\b/.test(node.className)) {
        return true;
      }
      return false;
    }
    RE.focus = function(){
        quill.focus();
    }
    RE.callback = function(modify_post) {
        if (!RE.inKbApp) {
            return;
        }
        JavaInterface.callback(RE.getHtml(),modify_post ? true : false);
    }
    RE.enabledEditingItems = function() {
        var format = quill.getFormat();
        var items = [];
        if (format.bold) {
            items.push('bold');
        }
        if (format.italic) {
            items.push('italic');
        }
        if (format.script === 'sub') {
            items.push('subscript');
        }
        if (format.script === 'super') {
            items.push('superscript');
        }
        if (format.strike) {
            items.push('strikeThrough');
        }
        if (format.underline) {
            items.push('underline');
        }
        if (format.list === 'ordered') {
            items.push('orderedList');
        }
        if (format.list === 'bullet') {
            items.push('unorderedList');
        }
        if (!format.align) {
            items.push('justifyLeft');
        } else if (format.align === 'center') {
            items.push('justifyCenter');
        } else if (format.align === 'right') {
            items.push('justifyRight');
        }
        if (format.header) {
            items.push('h' + format.header);
        }
        if (RE.inKbApp) {
            JavaInterface.stateCheck(items.join(','));
        }
    }
    RE.updateLink = function(id, url, value) {
        var display_value = value;
        if (display_value.length > 20) {
            display_value = display_value.substring(0,20) + "...";
        }
        var node = document.getElementById(id);
        node.setAttribute('data-link', url);
        node.setAttribute('data-value', value);
        node.setAttribute('value', display_value);
        node.style.width = getTextWidth(display_value) + 'px';
    }
    RE.insertEmotion = function(url, data_type, data_value){
        RE.insertKbItem('emoji', {
            'kb-tag': 'emoji',
            'src': url,
            'data-type': data_type,
            'data-value': data_value
        });

    }
    RE.insertContact = function(uid, value) {
        var display_value = value;
        if (display_value.length > 20) {
            display_value = display_value.substring(0,20) + "...";
        }
        RE.insertKbItem('contact', {
            'kb-tag': 'contact',
            'data-id': uid,
            'data-value': value,
            'value': display_value,
        });
    }

    RE.insertLink = function(id, url, value) {
        var display_value = value;
        if (display_value.length > 20) {
            display_value = display_value.substring(0,20) + "...";
        }
        RE.insertKbItem('link', {
            'kb-tag': 'link',
            'id': id,
            'data-link': url,
            'data-value': value,
            'value': display_value,
        });
    }

    RE.insertVideo = function(id,cover,title,duration) {
        var cls = "txt";
        if (!title) {
            cls = cls + ' txt-none';
        }
        var innerHTML = [
            '<div class="panel-vid" kb-tag="video" id="'+safeHtml(id,true)+'" data-duration="'+duration+'">',
                '<div class="img"><img src="'+cover+'"><span class="ico"></span>',
                    '<div class="progress"><span></span></div>',
                    '<div class="state">准备中...</div>',
                '</div>',
                '<div class="'+cls+'">'+safeHtml(title)+'</div>',
            '</div>'
        ].join('');
        RE.insertKbItem('video', innerHTML);
    }
    //视频设置进度
    RE.setVidProgress = function(id,percentage,speed){
        var progress = $('#'+id).find('.progress');
        progress.find('span').width(percentage+'%');
        var state = $('#'+id).find('div.state');
        if(!state.length){
          progress.after($('<div class="state">上传中 '+percentage+'%   '+speed+'</div>'));
        }else{
          state.text('上传中 '+percentage+'%   '+speed);
        }
    }
    //视频上传成功token
    RE.updateVidData = function(id,token,videoId){
        var ele = $('#'+id);
        ele.attr('data-token',token);
        ele.attr('data-id',videoId);
        var progress = ele.find('.progress');
        progress.find('span').width('100%');
        ele.find('div.state').remove();
        progress.after($('<div class="state succ">上传成功</div>'));
    }
    //视频上传失败
    RE.updateVidError = function(id){
        var ele = $('#'+id);
        ele.find('span.again').remove();
        ele.find('div.state').remove();
        ele.find('div.progress').after($('<span class="again">重新上传</span><div class="state fail">上传失败</div>'));
    }
    RE.deleteVideo = function(id){
        $('#'+id).parent().remove();
    }
    RE.resumeVideoUpload = function(id){
        var ele = $('#'+id);
        ele.find('span.again').remove();
        ele.find('div.state').remove();
        ele.find('.progress').after($('<div class="state">上传中...</div>'));
    }
    //视频更改封面和标题
    RE.setVidInfo = function(id, src, tit) {
        var ele = $('#' + id)
        if (src) {
            ele.find('.img img').remove();
            ele.find('.img').append($('<img src="' + safeHtml(src, true) + '">'));
        }
        var $tit = ele.find('.txt');
        $tit.text(tit);
        if (tit) {
            $tit.removeClass('txt-none');
        } else {
            $tit.addClass('txt-none');
        }
    }
    RE.insertVote = function(id, title, num, type, endTime) {
        var innerHTML = [
            '<div class="panel-vote" kb-tag="vote" id="'+safeHtml(id,true)+'">',
                '<div class="inner">',
                    '<div class="item">'+safeHtml(title)+'</div>',
                    '<div class="info"><span class="opt_count">'+(0|num)+'个选项 / '+safeHtml(type)+'</span><span class="end_time">投票截止：'+safeHtml(endTime)+'</span></div>',
                '</div>',
            '</div>'
        ].join('');
        RE.insertKbItem('vote', innerHTML);
    }
    RE.updateVote = function(id, title, num, type, endTime) {
        var $vote = $('#'+id);
        $vote.find('.item').text(safeHtml(title));
        $vote.find('.opt_count').text(num+'个选项 / ' + safeHtml(type));
        $vote.find('.end_time').text('投票截止：' + safeHtml(endTime));
        $vote.find('.state').remove();
    }
    // 合集
    RE.insertCollection = function(id,cId,icon,title,desc) {
        desc = desc || "";
        var innerHTML = [
            '<div class="panel-heji" kb-tag="collection" id="'+id+'" data-id="'+safeHtml(cId,true)+'">',
                '<div class="inner cf">',
                    '<div class="img">',
                        '<img class="big" src="'+safeHtml(icon,true)+'">',
                        '<div class="chip">游戏单</div>',
                    '</div>',
                    '<div class="con">',
                        '<div class="name">'+safeHtml(title)+'</div>',
                        '<div class="info">'+safeHtml(desc)+'</div>',
                    '</div>',
                '</div>',
            '</div>'
        ].join('');
        RE.insertKbItem('collection', innerHTML);
    }

    RE.updateCollection = function(id,cId,icon,title,desc){
      desc = desc || "";
      $('#'+id).attr('data-id',safeHtml(cId,true));
      $('#'+id).find('.img img').attr('src',safeHtml(icon,true));
      $('#'+id).find('.con .name').text(title);
      $('#'+id).find('.con .info').text(desc);
    }

    // 游戏
    RE.insertGame = function(id,icon,name,label,score,tag1,tag2,tag3,gameId,gameType) {
        label = label ? '<span>'+label+'</span>' : '';
        var gt='';
        if(gameType){
          if(gameType === 'fast'){
            gt='<span class="sp">快</span>'
          }else{
            gt='<span class="sp">云</span>'
          }
        }
        score = score ? '<span class="score">'+score+'</span>' : "";
        var innerHTML = [
            '<div class="panel-game" kb-tag="game"',
            'id="'+id+'"',
            'data-id="'+gameId+'"',
            'data-ext="'+gameType+'"',
            '>',
            '<div class="inner cf">',
              '<div class="img"><img src="'+icon+'"/>'+gt,
              '</div>',
              '<div class="con">',
                  '<div class="name">',
                      '<em>'+name+'</em>'+label,
                  '</div>',
                  '<div class="info">'+score,
                      '<span>'+tag1+'</span>',
                      '<span>'+tag2+'</span>',
                      '<span>'+tag3+'</span>',
                  '</div>',
              '</div>',
            '</div>',
            '</div>'
        ].join('');
        RE.insertKbItem('game', innerHTML);
    }

    RE.updateGame = function(id,icon,name,label,score,tag1,tag2,tag3,gameId,gameType) {
      var ele = $('#'+id);
      ele.attr('data-id',gameId);
      ele.attr('data-ext',gameType);
      label = label ? '<span>'+label+'</span>' : '';
      var gt='';
      if(gameType){
        if(gameType === 'fast'){
          gt='<span class="sp">快</span>'
        }else{
          gt='<span class="sp">云</span>'
        }
      }
      score = score ? '<span class="score">'+score+'</span>' : "";
      var html = [
        '<div class="inner cf">',
          '<div class="img"><img src="'+icon+'"/>'+gt,
          '</div>',
          '<div class="con">',
              '<div class="name">',
                  '<em>'+name+'</em>'+label,
              '</div>',
              '<div class="info">'+score,
                  '<span>'+tag1+'</span>',
                  '<span>'+tag2+'</span>',
                  '<span>'+tag3+'</span>',
              '</div>',
          '</div>',
        '</div>'
        ]
      ele.html(html.join(''));
    }

    RE.insertPic = function(id, picType, width, height, display_height) {
        var innerHTML = ['<div class="panel-pic" kb-tag="img"',
        ' id="'+id+'"',
        ' data-type="'+picType+'"',
        ' data-w="'+width+'"',
        ' data-h="'+height+'"',
        ' style=height:'+display_height+'px',
        '>',
        '</div>'].join('');
        RE.insertKbItem('img', innerHTML);
    }

    RE.deletePic = function(id){
        $('#'+id).parent().remove();
    }
    RE.updatePic = function(id,src){
        if (!$('#'+id).find('img').length) {
          $('#'+id).append($('<img/>'));
        }
        $('#'+id).css('background','none');
        $('#'+id).find('img').attr('src',src);
    }

    RE.insertLine = function() {
        var innerHTML = '<div class="line" kb-tag="line"></div>';
        RE.insertKbItem('line', innerHTML);
    }

    RE.insertLineDotted = function () {
        var innerHTML = '<div class="line dotted" kb-tag="line"></div>';
        RE.insertKbItem('line', innerHTML);
    }
    RE.formatToServer = function() {
      JavaInterface.formatHtml(RE.formatDoms(quill.root));
    }
    RE.formatDoms = function(doms) {
      var html = '';
      $(doms).contents().each(function(index, dom){
        var $dom = $(dom);
        switch (dom.nodeType) {
            case 1: // 元素
                var tagName = dom.tagName;
                var sty = "";
                if ($dom.hasClass("ql-align-center")) { // 居中
                  sty = ' style="text-align:center"';

                } else if ($dom.hasClass("ql-align-right")) { // 居右
                  sty = ' style="text-align:right"';
                }
                if (tagName == "H1") {
                    html += '<h1'+sty+'>'+RE.formatDoms(dom)+'</h1>';
                } else if (tagName == "H2") {
                    html += '<h2'+sty+'>'+RE.formatDoms(dom)+'</h2>';
                }else if (tagName == "OL") {
                    html += '<ol>'+RE.formatDoms(dom)+'</ol>';
                }else if (tagName == "UL") {
                    html += '<ul>'+RE.formatDoms(dom)+'</ul>';
                }else if (tagName == "LI") {
                    html += '<li>'+RE.formatDoms(dom)+'</li>';
                }else if (tagName == "P") {
                    if (dom.firstChild && dom.firstChild.nodeName === "BR") {
                        // 最后一行是空行且前一个是插卡
                        if (!dom.nextSibling && isKbPanel(dom.previousSibling)) {
                            break;
                        }
                    }
                    html += '<div'+sty+'>'+RE.formatDoms(dom)+'</div>';
                }else if (tagName == 'STRONG' || tagName == "B") {
                    html += '<b>'+RE.formatDoms(dom)+'</b>'
                }else if (tagName == "SPAN") {
                    html += RE.formatDoms(dom);
                } else if (tagName == 'INPUT') {
                  var kb_tag = $dom.attr('kb-tag');
                  if(kb_tag === "link"){
                    html += '<kb-link data-link="'+$dom.attr('data-link')+'" data-value="'+$dom.attr('data-value')+'"/>';
                  }else{
                    html += '<kb-contact data-id="'+$dom.attr('data-id')+'" data-value="@'+$dom.attr('value')+'"/>';
                  }
                } else if (tagName == 'IMG' && $dom.attr('kb-tag') == "emoji") {
                    html += '<kb-emoji src="'+$dom.attr('src')+'" data-value="'+$dom.attr('data-value')+'"/>';
                } else if (tagName == "DIV") {
                  if($dom.attr('contenteditable') === 'false'){
                    html += RE.formatDoms(dom);
                  }else{
                    var kb_tag = $dom.attr('kb-tag');
                    if (kb_tag === "video") {
                        var dataposter = $dom.find('img').attr('src');
                        var datatitle = $dom.find('.txt').text();
                        if(datatitle === '有趣的标题能获得更多的关注~'){
                          datatitle = '';
                        }
                        var dataid = $dom.attr('data-id');
                        var datatoken= $dom.attr('data-token');
                        var dataExt='2';
                        if($dom.attr('data-ext')){
                           dataExt = $dom.attr('data-ext');
                        }
                        html += '<kb-video src="" data-poster="'+dataposter+'" data-ext="'+dataExt+'" data-id="'+dataid+'" data-title="'+datatitle+'" data-token="'+datatoken+'"/>';
                    } else if (kb_tag === "vote") {
                        var dataid = '',dataExt='';
                        if($dom.attr('data-id')){
                          dataid = $dom.attr('data-id');
                        }else{
                          dataExt = ' data-ext="'+$dom.attr('id')+'"';
                        }
                        html += '<kb-vote data-id="'+dataid+'" data-value="'+$dom.find('.item').text()+'"'+dataExt+'/>';
                    } else if (kb_tag === "collection") {
                        html += '<kb-collection data-id="'+$dom.attr('data-id')+'" data-value="'+$dom.find('.name').text()+'"/>';
                    }else if (kb_tag === "game") {
                       html += '<kb-game data-id="'+$dom.attr('data-id')+'" data-value="'+$dom.find('em').text()+'" data-ext="'+$dom.attr('data-ext')+'"/>';
                     }else if (kb_tag === "img") {
                       html += '<kb-img src="'+$dom.find('img').attr('src')+'" data-width="'+$dom.attr('data-w')+'" data-height="'+$dom.attr('data-h')+'" data-ext="'+$dom.attr('data-type')+'"/>';
                     }else if (kb_tag === "line") {
                       var data_ext = $dom.hasClass('dotted') ? "2" : "1";
                       html += '<kb-line data-ext="'+data_ext+'"/>';
                     } else if ($dom.attr('style')) {
                         var text_align = dom.style.textAlign;
                         if (text_align) {
                             html += '<div style="text-align: '+text_align+'">' + RE.formatDoms(dom) + '</div>';
                         } else {
                            html += RE.formatDoms(dom);
                         }
                     }else {
                        html += '<div>'+RE.formatDoms(dom)+'</div>';
                    }
                  }
              } else {
                  html += dom.outerHTML;
              }
              break;
           case 3: // 纯文本
             html += dom.nodeValue.replace(/&/g,'&amp;').replace(/</g,'&lt;').replace(/>/g,'&gt;').replace(/( |\u00a0)/g,'&nbsp;');
           break;
        }
      });
    return html;
    }
    RE.formatReplyToServer = function() {
      JavaInterface.formatHtml(RE.formatReply(quill.root));
    }
    RE.formatReply = function(doms) {
      var html = '';
      $(doms).contents().each(function(index, dom){
        var $dom = $(dom);
        switch (dom.nodeType) {
            case 1: // 元素
                var tagName = dom.tagName;
                if (tagName == "H1") {
                    html += '<h1>'+RE.formatReply(dom)+'</h1>';
                } else if (tagName == "H2") {
                    html += '<h2>'+RE.formatReply(dom)+'</h2>';
                }else if(tagName == "BR"){
                  html += '<br>';
                }else if (tagName == "OL") {
                    html += '<ol>'+RE.formatReply(dom)+'</ol>';
                }else if (tagName == "UL") {
                    html += '<ul>'+RE.formatReply(dom)+'</ul>';
                }else if (tagName == "LI") {
                    html += '<li>'+RE.formatReply(dom)+'</li>';
                }else if (tagName == "P") {
                    if (dom.firstChild && dom.firstChild.nodeName === "BR") {
                        // 有下一行或者不是插卡后的最后一行
                        if (dom.nextSibling || !isKbPanel(dom.previousSibling)) {
                            html += "<br>";
                        }
                    } else {
                        html += RE.formatReply(dom);
                        // 由于旧版插卡会自动换行，所以下一个是插卡的时候，不自动加br
                        if (dom.nextSibling && !isKbPanel(dom.nextSibling)) {
                          html += '<br>';
                        }
                    }
                }else if (tagName == 'STRONG' || tagName == "B") {
                    html += '<b>'+$dom.text()+'</b>';
                }else if (tagName == "SPAN") {
                    html += RE.formatReply(dom);
                } else if (tagName == 'INPUT') {
                  var kb_tag = $dom.attr('kb-tag');
                  if(kb_tag === "link"){
                    html += '<kb-link data-link="'+$dom.attr('data-link')+'" data-value="'+$dom.attr('data-value')+'"/>';
                  }else{
                    html += '<kb-contact data-id="'+$dom.attr('data-id')+'" data-value="@'+$dom.attr('value')+'"/>';
                  }
                } else if (tagName == 'IMG' && $dom.attr('kb-tag') == "emoji") {
                    html += '<kb-emoji src="'+$dom.attr('src')+'" data-value="'+$dom.attr('data-value')+'"/>';
                } else if (tagName == "DIV") {
                  if(isKbPanel(dom)){
                    html += RE.formatReply(dom);
                  }else{
                    var kb_tag = $dom.attr('kb-tag');
                    if (kb_tag === "img") {
                       html += '<kb-img src="'+$dom.find('img').attr('src')+'" data-width="'+$dom.attr('data-w')+'" data-height="'+$dom.attr('data-h')+'" data-ext="'+$dom.attr('data-type')+'"/>';
                    }
                  }
                } else {
                   html += dom.innerText;
                }

              break;
          case 3: // 纯文本
              html += dom.nodeValue.replace(/&/g,'&amp;').replace(/</g,'&lt;').replace(/>/g,'&gt;').replace(/( |\u00a0)/g,'&nbsp;');
              break;
        }
      });
    return html;
    }

    RE.checkImageUpload =function() {
        var yes = true;
        $('div[kb-tag=img]').each(function(){
          if (!yes) {
            return;
          }
          var $img = $(this).find('img');
          if (!$img.length) {
              yes = false;
              return;
          }
          var src = $img.attr('src');
          if (!src || src.indexOf('http') === -1) {
            yes = false;
            return;
          }
        });
        JavaInterface.checkImgUpload(yes ? "1" : "0");
    }

    //保存草稿是否退出页面
    RE.getDraftContent =function(type) {
       var $editor = RE.deleteNoSrcAndNoVideo();
       JavaInterface.buildDraftContent(RE.getDraftContentDom($editor),"<p><br></p>" === $editor.html() ? '' : $editor.html(),type);
    }

    RE.enableVoteModify = function(){
      $(quill.root).find('div[kb-tag=vote]').removeAttr('disable-modify').attr('data-id','');
    }

    RE.getDraftDeleteNoSrc =function(){
      RE.hideItemTool();
      JavaInterface.deleteNoSrcAndNoVideo(RE.deleteNoSrcAndNoVideo().html());
    }
    RE.deleteNoSrcAndNoVideo = function(){
       var $editor = $(quill.root).clone();
        $editor.find('div[kb-tag=img]').each(function(){
           var $this = $(this);
           if (!$this.find('img').length || !$this.find('img').attr('src')) {
               $this.parent().remove();
           }
        });
        $editor.find('div[kb-tag=video]').each(function(){
           var $this = $(this);
           if (!$this.attr('data-id')) {
               $this.parent().remove();
           }
        });
       return $editor;
    }

    RE.getDraftContentDom =function(doms) {
       var html = '';
       var kb_tag;
       $(doms).contents().each(function(index, dom){
           var $dom = $(dom);
           switch (dom.nodeType) {
               case 1: // 元素
                    var tagName = dom.tagName;
                   if (tagName == "H1") {
                       html += RE.getDraftContentDom(dom);
                   } else if (tagName == "H2") {
                       html += RE.getDraftContentDom(dom);
                   }else if (tagName == "OL") {
                       html += RE.getDraftContentDom(dom);
                   }else if (tagName == "UL") {
                       html += RE.getDraftContentDom(dom);
                   }else if (tagName == "LI") {
                       html += RE.getDraftContentDom(dom);
                   }else if (tagName == "P") {
                       html += RE.getDraftContentDom(dom);
                   }else if (tagName == 'STRONG' || tagName == "B") {
                       html += $dom.text();
                   }else if (tagName == "SPAN") {
                       html += RE.getDraftContentDom(dom);
                   } else if (tagName == 'INPUT' && $dom.attr('kb-tag')) {
                      if($dom.attr('kb-tag') === 'link'){
                         html += '【链接】'
                      }else{
                         html += '@'+$dom.attr('value');
                      }
                   } else if (tagName == 'IMG' && $dom.attr('kb-tag') == "emoji") {
                       html += '【表情】';
                   } else if (tagName == "DIV") {
                      if($dom.attr('contenteditable') === 'false'){
                          html += RE.getDraftContentDom(dom);
                      }else{
                        kb_tag = $dom.attr('kb-tag');
                       if ((kb_tag === "img" && !$dom.find('img').attr('src')) || (kb_tag === "video" && !$dom.attr('data-id'))) {
                         html += '';
                       }else if (kb_tag === "video") {
                           html += '【视频】';
                       } else if (kb_tag === "vote") {
                           html += '【投票】';
                       } else if (kb_tag === "collection") {
                           html += '【游戏单】';
                       }else if (kb_tag === "game") {
                          html += '【游戏】';
                        }else if (kb_tag === "img") {
                          html += '【图片】';
                        }else if (kb_tag === "line") {
                          html += '';
                        } else {
                           html += RE.getDraftContentDom(dom);
                       }
                      }
                 } else {
                     html += dom.innerText;
                 }
                 break;
             case 3: // 纯文本
                 html += dom.nodeValue;
                 break;
           }
         });
         return html;
    }
    //光标移动到末尾
    RE.moveToEnd = function() {
       quill.setSelection(quill.getLength(), 0);
    }
    // 字数统计
    RE.wordCount = function() {
        var all_wc = quill.root.innerText.replace(/\s/g, '').length,
            vote_num = 0,
            video_num = 0,
            gif_num = 0,
            img_num = 0,
            delta_wc = 0;
        $(quill.root).find('[kb-tag]').each(function(){
            var tag = this.getAttribute('kb-tag');
            if (this.nodeName === "INPUT") {
                if (tag === "link" || tag === "contact") {
                    delta_wc += this.value.replace(/\s/g, '').length;
                }
            } else if (this.tagName === "DIV") {
                delta_wc -= this.innerText.replace(/\s/g, '').length;
            }
            var imgType = this.getAttribute('data-type');
            // 需要算一个字符的标签
            if (tag === "img") { // 图片算一个字符
                delta_wc += 1;
                img_num += 1;
                if(imgType && imgType === "gif"){
                    gif_num += 1;
                }
            } else if (tag === "emoji") { // 表情算一个字符
                delta_wc += 1;
            }else if(tag === "vote"){
                vote_num += 1;
            }else if(tag === "video"){
                video_num += 1;
            }
        });
        if (RE.inKbApp) {
            JavaInterface.countTextNum(all_wc + delta_wc,vote_num,video_num,img_num,gif_num);
        }
    }
    // 视频重新上传
    $('body').on('click', 'span.again', function(){
      var $div = $(this).closest('div[kb-tag]');
      if (!$div.length) {
          return false;
      }
      $div.find('span.again').remove();
      $div.find('div.state').remove();
      $div.find('.progress').after($('<div class="state">准备中...</div>'));
      var cover = $div.find('img');
      cover.attr('src',cover.attr('src'));
      if (RE.inKbApp) {
        JavaInterface.reUpdateVideo();
      }
      $(quill.root).blur();
      return false;
    });

    //编辑
    $('body').on('click', 'span.edit', function(){
        var $div = $(this).closest('div[kb-tag]');
        if (!$div.length) {
            return false;
        }
        var id = $div.attr('id');
        var kb_tag = $div.attr('kb-tag');
        var data = null;
        if (kb_tag === 'video') {
            data = {
                coverUrl: $div.find('img').attr('src'),
                videoDuration: $div.attr('data-duration') || "",
                title: $div.find('.txt').text()
            };
        }
        if (RE.inKbApp) {
            JavaInterface.edit(id, data ? JSON.stringify(data) : "", kb_tag);
        }
        RE.hideItemTool();
        return false;
    });
    RE.editPanel = function(node){
        if (RE.inKbApp) {
            JavaInterface.updateLink(node.getAttribute('id'), node.getAttribute('data-value'), node.getAttribute('data-link'));
        }
    }
    RE.delPanel = function(node) {
        if (RE.inKbApp) {
            JavaInterface.del(node.getAttribute('id'),node.getAttribute('kb-tag'));
        }
    }
})();